@@ -10,13 +10,13 @@ class Version(object):
     Version handling for pysotsog
     '''
     name="pysotsog"
-    description='''python Library for Scholars to achieve "Standing on the shoulders of giants"'''
+    description='sotsog: Standing on the shoulders of giants - with direct access to the clouds'
     version=skg.__version__
     date = '2022-11-16'
-    updated = '2022-11-18'
-    description='Scholarly Knowledge Graph Search with Commandline and Browser'
+    updated = '2022-11-24'
     authors='Wolfgang Fahl'
     doc_url="https://wiki.bitplan.com/index.php/Pysotsog"
+    chat_url="https://github.com/WolfgangFahl/pysotsog/discussions"
     cm_url="https://github.com/WolfgangFahl/pysotsog"
     license=f'''Copyright 2022 contributors. All rights reserved.
   Licensed under the Apache License 2.0
